"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const os_1 = tslib_1.__importDefault(require("os"));
const package_json_1 = require("./package-json");
describe('determineLanguagesUsed', () => {
    it('should loop through core programming languages and return array of languages used', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const packageJsonMap = new Map([
            ['@angular/core', { name: '@angular/core', version: '7.0.1' }],
            ['react', { name: 'react', version: '16.7.0' }],
            ['vue', { name: 'vue', version: '15.0.0' }]
        ]);
        expect(yield (0, package_json_1.determineLanguagesUsed)(packageJsonMap)).toEqual(['angular', 'react', 'vue']);
    }));
});
describe('determineLanguageWithVersionUsed', () => {
    it('should loop through core programming languages and return array of languages used with version', () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const packageJsonMap = new Map([
            ['@angular/core', { name: '@angular/core', version: '7.0.1' }],
            ['react', { name: 'react', version: '16.7.9' }],
            ['vue', { name: 'vue', version: '15.0.5' }],
            ['garbage', { name: 'garbage', version: '1.2.3' }]
        ]);
        expect(yield (0, package_json_1.determineLanguagesWithVersionUsed)(packageJsonMap)).toEqual(['angular-7.0.0', 'react-16.7.0', 'vue-15.0.0']);
    }));
});
describe('searchForPackageJson', () => {
    let tmpDir;
    beforeEach(() => {
        tmpDir = fs_1.default.mkdtempSync(path_1.default.join(os_1.default.tmpdir(), 'my-tmp-dir-'));
    });
    afterEach(() => {
        fs_1.default.rmdirSync(tmpDir, { recursive: true });
    });
    it('should return the path to the package.json file if it exists', () => {
        fs_1.default.writeFileSync(path_1.default.join(tmpDir, 'package.json'), '{}');
        const result = (0, package_json_1.searchForPackageJson)(tmpDir);
        expect(result).toEqual(tmpDir);
    });
    it('should return null if the package.json file is not found', () => {
        const result = (0, package_json_1.searchForPackageJson)(tmpDir);
        expect(result).toBeNull();
    });
});
